# hkvsobekpy
package for water-statistics and plausibility checker using his- and bui-files

install
`pip install hkvsobekpy`

# depdencies
hkvsobekpy requires the following packages to be installed:
- tqdm
- fire
- numpy
- scipy
- pandas
- geopandas (requires Fiona and GDAL)

The package will install tqdm and fire as dependencies, but the other packgages are not included, since Windows cannot compile these packages from source. 
Go to https://www.lfd.uci.edu/~gohlke/pythonlibs to download these packages on Windows, or `use pip install`.

